@@ -1,11 +1,19 @@
 __author__ = 'tunnell'
 
 
-def print_to_screen(results):
+def print_samples_to_screen(results):
     for E, l, angle in results:
         print 'E_mu: %g GeV\tL: %g km\tangle:%g rad' % (E, l, angle)
 
 
+def print_events_to_screen(events):
+    print 'Total number of events:'
+    for key, value in events.iteritems():
+        flavor, polarity = key
+
+        print '\t', flavor, polarity, value
+
+
 def create_plot(name, results, use_matplotlib=True):
     """Create plot with matplotlib"""
 
